summaryrefslogtreecommitdiffstats
path: root/epan/golay.h
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-09-19 04:14:53 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-09-19 04:14:53 +0000
commita86c5f7cae7ec9a3398300555a0b644689d946a1 (patch)
tree39fe4b107c71174fd1e8a8ceb9a4d2aa14116248 /epan/golay.h
parentReleasing progress-linux version 4.2.6-1~progress7.99u1. (diff)
downloadwireshark-a86c5f7cae7ec9a3398300555a0b644689d946a1.tar.xz
wireshark-a86c5f7cae7ec9a3398300555a0b644689d946a1.zip
Merging upstream version 4.4.0.
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'epan/golay.h')
-rw-r--r--epan/golay.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/epan/golay.h b/epan/golay.h
index 9711f068..838f99f8 100644
--- a/epan/golay.h
+++ b/epan/golay.h
@@ -5,7 +5,7 @@
* This implementation will detect up to 4 errors in a codeword (without
* being able to correct them); it will correct up to 3 errors.
*
* We use guint32s to hold the 24-bit codewords, with the data part in
* the bottom 12 bits and the parity in bits 12-23.
*
*
@@ -18,25 +18,27 @@
#ifndef __GOLAY_H__
#define __GOLAY_H__
+#include <stdint.h>
+
#include "ws_symbol_export.h"
/* encodes a 12-bit word to a 24-bit codeword
*/
WS_DLL_PUBLIC
-guint32 golay_encode(guint w);
+uint32_t golay_encode(unsigned w);
/* return a mask showing the bits which are in error in a received
* 24-bit codeword, or -1 if 4 errors were detected.
*/
WS_DLL_PUBLIC
-gint32 golay_errors(guint32 codeword);
+int32_t golay_errors(uint32_t codeword);
/* decode a received codeword. Up to 3 errors are corrected for; 4
errors are detected as uncorrectable (return -1); 5 or more errors
cause an incorrect correction.
*/
WS_DLL_PUBLIC
-gint golay_decode(guint32 w);
+int golay_decode(uint32_t w);
#endif
@@ -5,7 +5,7 @@
* being able to correct them); it will correct up to 3 errors.
*
- * We use guint32s to hold the 24-bit codewords, with the data part in
+ * We use uint32_t to hold the 24-bit codewords, with the data part in
* the bottom 12 bits and the parity in bits 12-23.
*